==> knative-model-4.4.1-sources.jar: io/fabric8/knative/messaging/v1alpha1/SequenceStatusFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.ConditionBuilder;
import javax.validation.Valid;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SequenceStatusFluent<A extends SequenceStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public SequenceStatusFluent.AddressNested<A> withNewAddress();
    public SequenceStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public SequenceStatusFluent.AddressNested<A> editAddress();
    public SequenceStatusFluent.AddressNested<A> editOrNewAddress();
    public SequenceStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToChannelStatuses(int index,SequenceChannelStatus item);
    public A setToChannelStatuses(int index,SequenceChannelStatus item);
    public A addToChannelStatuses(SequenceChannelStatus... items);
    public A addAllToChannelStatuses(Collection<SequenceChannelStatus> items);
    public A removeFromChannelStatuses(SequenceChannelStatus... items);
    public A removeAllFromChannelStatuses(Collection<SequenceChannelStatus> items);
    
/**
 * This method has been deprecated, please use method buildChannelStatuses instead.
 * @return The buildable object.
 */
@Deprecated public List<SequenceChannelStatus> getChannelStatuses();
    public List<SequenceChannelStatus> buildChannelStatuses();
    public SequenceChannelStatus buildChannelStatus(int index);
    public SequenceChannelStatus buildFirstChannelStatus();
    public SequenceChannelStatus buildLastChannelStatus();
    public SequenceChannelStatus buildMatchingChannelStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceChannelStatusBuilder> predicate);
    public Boolean hasMatchingChannelStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceChannelStatusBuilder> predicate);
    public A withChannelStatuses(List<SequenceChannelStatus> channelStatuses);
    public A withChannelStatuses(SequenceChannelStatus... channelStatuses);
    public Boolean hasChannelStatuses();
    public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatus();
    public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatusLike(SequenceChannelStatus item);
    public SequenceStatusFluent.ChannelStatusesNested<A> setNewChannelStatusLike(int index,SequenceChannelStatus item);
    public SequenceStatusFluent.ChannelStatusesNested<A> editChannelStatus(int index);
    public SequenceStatusFluent.ChannelStatusesNested<A> editFirstChannelStatus();
    public SequenceStatusFluent.ChannelStatusesNested<A> editLastChannelStatus();
    public SequenceStatusFluent.ChannelStatusesNested<A> editMatchingChannelStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceChannelStatusBuilder> predicate);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public SequenceStatusFluent.ConditionsNested<A> addNewCondition();
    public SequenceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public SequenceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public SequenceStatusFluent.ConditionsNested<A> editCondition(int index);
    public SequenceStatusFluent.ConditionsNested<A> editFirstCondition();
    public SequenceStatusFluent.ConditionsNested<A> editLastCondition();
    public SequenceStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToSubscriptionStatuses(int index,SequenceSubscriptionStatus item);
    public A setToSubscriptionStatuses(int index,SequenceSubscriptionStatus item);
    public A addToSubscriptionStatuses(SequenceSubscriptionStatus... items);
    public A addAllToSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
    public A removeFromSubscriptionStatuses(SequenceSubscriptionStatus... items);
    public A removeAllFromSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
    
/**
 * This method has been deprecated, please use method buildSubscriptionStatuses instead.
 * @return The buildable object.
 */
@Deprecated public List<SequenceSubscriptionStatus> getSubscriptionStatuses();
    public List<SequenceSubscriptionStatus> buildSubscriptionStatuses();
    public SequenceSubscriptionStatus buildSubscriptionStatus(int index);
    public SequenceSubscriptionStatus buildFirstSubscriptionStatus();
    public SequenceSubscriptionStatus buildLastSubscriptionStatus();
    public SequenceSubscriptionStatus buildMatchingSubscriptionStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceSubscriptionStatusBuilder> predicate);
    public Boolean hasMatchingSubscriptionStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceSubscriptionStatusBuilder> predicate);
    public A withSubscriptionStatuses(List<SequenceSubscriptionStatus> subscriptionStatuses);
    public A withSubscriptionStatuses(SequenceSubscriptionStatus... subscriptionStatuses);
    public Boolean hasSubscriptionStatuses();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatus();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatusLike(SequenceSubscriptionStatus item);
    public SequenceStatusFluent.SubscriptionStatusesNested<A> setNewSubscriptionStatusLike(int index,SequenceSubscriptionStatus item);
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editSubscriptionStatus(int index);
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editFirstSubscriptionStatus();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editLastSubscriptionStatus();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editMatchingSubscriptionStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceSubscriptionStatusBuilder> predicate);

    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<SequenceStatusFluent.AddressNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface ChannelStatusesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SequenceChannelStatusFluent<SequenceStatusFluent.ChannelStatusesNested<N>>{

        
    public N and();    public N endChannelStatus();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface SubscriptionStatusesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SequenceSubscriptionStatusFluent<SequenceStatusFluent.SubscriptionStatusesNested<N>>{

        
    public N and();    public N endSubscriptionStatus();
}


}

==> knative-model-4.6.4-sources.jar: io/fabric8/knative/messaging/v1alpha1/SequenceStatusFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SequenceStatusFluent<A extends SequenceStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.duck.v1alpha1.Addressable getAddress();
    public io.fabric8.knative.duck.v1alpha1.Addressable buildAddress();
    public A withAddress(io.fabric8.knative.duck.v1alpha1.Addressable address);
    public Boolean hasAddress();
    public SequenceStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
    public SequenceStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public SequenceStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
    public SequenceStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
    public SequenceStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public A addToChannelStatuses(int index,SequenceChannelStatus item);
    public A setToChannelStatuses(int index,SequenceChannelStatus item);
    public A addToChannelStatuses(SequenceChannelStatus... items);
    public A addAllToChannelStatuses(Collection<SequenceChannelStatus> items);
    public A removeFromChannelStatuses(SequenceChannelStatus... items);
    public A removeAllFromChannelStatuses(Collection<SequenceChannelStatus> items);
    
/**
 * This method has been deprecated, please use method buildChannelStatuses instead.
 * @return The buildable object.
 */
@Deprecated public List<SequenceChannelStatus> getChannelStatuses();
    public List<SequenceChannelStatus> buildChannelStatuses();
    public SequenceChannelStatus buildChannelStatus(int index);
    public SequenceChannelStatus buildFirstChannelStatus();
    public SequenceChannelStatus buildLastChannelStatus();
    public SequenceChannelStatus buildMatchingChannelStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceChannelStatusBuilder> predicate);
    public Boolean hasMatchingChannelStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceChannelStatusBuilder> predicate);
    public A withChannelStatuses(List<SequenceChannelStatus> channelStatuses);
    public A withChannelStatuses(SequenceChannelStatus... channelStatuses);
    public Boolean hasChannelStatuses();
    public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatus();
    public SequenceStatusFluent.ChannelStatusesNested<A> addNewChannelStatusLike(SequenceChannelStatus item);
    public SequenceStatusFluent.ChannelStatusesNested<A> setNewChannelStatusLike(int index,SequenceChannelStatus item);
    public SequenceStatusFluent.ChannelStatusesNested<A> editChannelStatus(int index);
    public SequenceStatusFluent.ChannelStatusesNested<A> editFirstChannelStatus();
    public SequenceStatusFluent.ChannelStatusesNested<A> editLastChannelStatus();
    public SequenceStatusFluent.ChannelStatusesNested<A> editMatchingChannelStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceChannelStatusBuilder> predicate);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public SequenceStatusFluent.ConditionsNested<A> addNewCondition();
    public SequenceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public SequenceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public SequenceStatusFluent.ConditionsNested<A> editCondition(int index);
    public SequenceStatusFluent.ConditionsNested<A> editFirstCondition();
    public SequenceStatusFluent.ConditionsNested<A> editLastCondition();
    public SequenceStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToSubscriptionStatuses(int index,SequenceSubscriptionStatus item);
    public A setToSubscriptionStatuses(int index,SequenceSubscriptionStatus item);
    public A addToSubscriptionStatuses(SequenceSubscriptionStatus... items);
    public A addAllToSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
    public A removeFromSubscriptionStatuses(SequenceSubscriptionStatus... items);
    public A removeAllFromSubscriptionStatuses(Collection<SequenceSubscriptionStatus> items);
    
/**
 * This method has been deprecated, please use method buildSubscriptionStatuses instead.
 * @return The buildable object.
 */
@Deprecated public List<SequenceSubscriptionStatus> getSubscriptionStatuses();
    public List<SequenceSubscriptionStatus> buildSubscriptionStatuses();
    public SequenceSubscriptionStatus buildSubscriptionStatus(int index);
    public SequenceSubscriptionStatus buildFirstSubscriptionStatus();
    public SequenceSubscriptionStatus buildLastSubscriptionStatus();
    public SequenceSubscriptionStatus buildMatchingSubscriptionStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceSubscriptionStatusBuilder> predicate);
    public Boolean hasMatchingSubscriptionStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceSubscriptionStatusBuilder> predicate);
    public A withSubscriptionStatuses(List<SequenceSubscriptionStatus> subscriptionStatuses);
    public A withSubscriptionStatuses(SequenceSubscriptionStatus... subscriptionStatuses);
    public Boolean hasSubscriptionStatuses();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatus();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> addNewSubscriptionStatusLike(SequenceSubscriptionStatus item);
    public SequenceStatusFluent.SubscriptionStatusesNested<A> setNewSubscriptionStatusLike(int index,SequenceSubscriptionStatus item);
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editSubscriptionStatus(int index);
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editFirstSubscriptionStatus();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editLastSubscriptionStatus();
    public SequenceStatusFluent.SubscriptionStatusesNested<A> editMatchingSubscriptionStatus(io.fabric8.kubernetes.api.builder.Predicate<SequenceSubscriptionStatusBuilder> predicate);

    public interface V1alpha1AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1alpha1.AddressableFluent<SequenceStatusFluent.V1alpha1AddressNested<N>>{

        
    public N and();    public N endV1alpha1Address();
}
    public interface ChannelStatusesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SequenceChannelStatusFluent<SequenceStatusFluent.ChannelStatusesNested<N>>{

        
    public N and();    public N endChannelStatus();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface SubscriptionStatusesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SequenceSubscriptionStatusFluent<SequenceStatusFluent.SubscriptionStatusesNested<N>>{

        
    public N and();    public N endSubscriptionStatus();
}


}
